#!/usr/bin/env python3
# @generated AUTOGENERATED file. Do not Change!

from dataclasses import dataclass, field as _field
from functools import partial
from ...config import custom_scalars, datetime
from numbers import Number
from typing import Any, AsyncGenerator, Dict, List, Generator, Optional

from dataclasses_json import DataClassJsonMixin, config


@dataclass(frozen=True)
class AddRuleInput(DataClassJsonMixin):
    name: str
    gracePeriod: int
    ruleType: str
    status: bool
    eventSeverity: str
    threshold: str
    startDateTime: Optional[datetime] = None
    endDateTime: Optional[datetime] = None
    eventTypeName: Optional[str] = None
    specificProblem: Optional[str] = None
    additionalInfo: Optional[str] = None
